pystagram.graph_api.endpoints.container package — pystagram 0.1 documentation

# pystagram.graph_api.endpoints.container package

## Submodules

## pystagram.graph_api.endpoints.container.container module

class pystagram.graph_api.endpoints.container.container.Container(graph_api: PystagramGraphApi)

  Bases: `object`

  The Container node of the Instagram Graph API. :param graph_api: An instance of the `InstagramGraphApi` class. :type graph_api: `InstagramGraphApi`

  create(*args, **kwargs)

    [Not Supported] Create an Instagram container. :raises InstagramApiEndpointError: Container creation is only supported by the User Media node

  delete(*args, **kwargs)

    [Not Supported] Delete an Instagram comment. :raises InstagramApiNotSupportedError: Container deletion is not supported by the Instagram Graph API.

  get(container_id: int, fields: List[str | ContainerFields] | None = None, access_token: str | None = None)

    Get fields and edges on an Instagram container. :param container_id: The ID of the container to get fields and edges from. :type container_id: int :param fields: A list of `pystagram.graph_api.components.fields.container_fields.ContainerFields` to get from the container, defaults to None :type fields: Optional[List[Union[str, ContainerFields]]], optional :param access_token: The access token of the Instagram user, inferred from the InstagramGraphApi instance if None, defaults to None :type access_token: str, optional :return: The response from the GET /{container-id} endpoint. :rtype: `pystagram.helpers.api_client.api_response.PystagramApiResponse`

  update(*args, **kwargs)

    [Not Supported] Update an Instagram comment. :raises InstagramApiNotSupportedError: Container update is not supported by the Instagram Graph API.

## Module contents